/**
 * MaterialDesign icon set component.
 * Usage: <MaterialDesign name="icon-name" size={20} color="#4F8EF7" />
 *
 * @providesModule MaterialDesign
 */
'use strict';

var createIconSet = require('createIconSet');
var glyphMap = {
  "3d-rotation": 61696,
  "access-alarm": 61697,
  "access-alarms": 61698,
  "access-time": 61699,
  "accessibility": 61700,
  "account-balance": 61701,
  "account-balance-wallet": 61702,
  "account-box": 61703,
  "account-circle": 61704,
  "adb": 61705,
  "add": 61706,
  "add-alarm": 61707,
  "add-box": 61708,
  "add-circle": 61709,
  "add-circle-outline": 61710,
  "add-shopping-cart": 61711,
  "add-to-photos": 61712,
  "adjust": 61713,
  "airplanemode-off": 61714,
  "airplanemode-on": 61715,
  "alarm": 61716,
  "alarm-add": 61717,
  "alarm-off": 61718,
  "alarm-on": 61719,
  "album": 61720,
  "android": 61721,
  "announcement": 61722,
  "apps": 61723,
  "archive": 61724,
  "arrow-back": 61725,
  "arrow-drop-down": 61726,
  "arrow-drop-down-circle": 61727,
  "arrow-drop-up": 61728,
  "arrow-forward": 61729,
  "aspect-ratio": 61730,
  "assessment": 61731,
  "assignment": 61732,
  "assignment-ind": 61733,
  "assignment-late": 61734,
  "assignment-return": 61735,
  "assignment-returned": 61736,
  "assignment-turned-in": 61737,
  "assistant-photo": 61738,
  "attach-file": 61739,
  "attach-money": 61740,
  "attachment": 61741,
  "audiotrack": 61742,
  "autorenew": 61743,
  "av-timer": 61744,
  "backspace": 61745,
  "backup": 61746,
  "battery-20": 61747,
  "battery-30": 61748,
  "battery-50": 61749,
  "battery-60": 61750,
  "battery-80": 61751,
  "battery-90": 61752,
  "battery-alert": 61753,
  "battery-charging-20": 61754,
  "battery-charging-30": 61755,
  "battery-charging-50": 61756,
  "battery-charging-60": 61757,
  "battery-charging-80": 61758,
  "battery-charging-90": 61759,
  "battery-charging-full": 61760,
  "battery-full": 61761,
  "battery-std": 61762,
  "battery-unknown": 61763,
  "beenhere": 61764,
  "block": 61765,
  "bluetooth": 61766,
  "bluetooth-audio": 61767,
  "bluetooth-connected": 61768,
  "bluetooth-disabled": 61769,
  "bluetooth-searching": 61770,
  "blur-circular": 61771,
  "blur-linear": 61772,
  "blur-off": 61773,
  "blur-on": 61774,
  "book": 61775,
  "bookmark": 61776,
  "bookmark-outline": 61777,
  "border-all": 61778,
  "border-bottom": 61779,
  "border-clear": 61780,
  "border-color": 61781,
  "border-horizontal": 61782,
  "border-inner": 61783,
  "border-left": 61784,
  "border-outer": 61785,
  "border-right": 61786,
  "border-style": 61787,
  "border-top": 61788,
  "border-vertical": 61789,
  "brightness-1": 61790,
  "brightness-2": 61791,
  "brightness-3": 61792,
  "brightness-4": 61793,
  "brightness-5": 61794,
  "brightness-6": 61795,
  "brightness-7": 61796,
  "brightness-auto": 61797,
  "brightness-high": 61798,
  "brightness-low": 61799,
  "brightness-medium": 61800,
  "brush": 61801,
  "bug-report": 61802,
  "business": 61803,
  "cached": 61804,
  "cake": 61805,
  "call": 61806,
  "call-end": 61807,
  "call-made": 61808,
  "call-merge": 61809,
  "call-missed": 61810,
  "call-received": 61811,
  "call-split": 61812,
  "camera": 61813,
  "camera-alt": 61814,
  "camera-front": 61815,
  "camera-rear": 61816,
  "camera-roll": 61817,
  "cancel": 61818,
  "cast": 61819,
  "cast-connected": 61820,
  "center-focus-strong": 61821,
  "center-focus-weak": 61822,
  "chat": 61823,
  "check": 61824,
  "check-box": 61825,
  "check-box-outline-blank": 61826,
  "check-circle": 61827,
  "chevron-left": 61828,
  "chevron-right": 61829,
  "class": 61830,
  "clear": 61831,
  "clear-all": 61832,
  "close": 61833,
  "closed-caption": 61834,
  "cloud": 61835,
  "cloud-circle": 61836,
  "cloud-done": 61837,
  "cloud-download": 61838,
  "cloud-off": 61839,
  "cloud-queue": 61840,
  "cloud-upload": 61841,
  "collections": 61842,
  "color-lens": 61843,
  "colorize": 61844,
  "comment": 61845,
  "compare": 61846,
  "computer": 61847,
  "contacts": 61848,
  "content-copy": 61849,
  "content-cut": 61850,
  "content-paste": 61851,
  "control-point": 61852,
  "control-point-duplicate": 61853,
  "create": 61854,
  "credit-card": 61855,
  "crop": 61856,
  "crop-16-9": 61857,
  "crop-3-2": 61858,
  "crop-5-4": 61859,
  "crop-7-5": 61860,
  "crop-din": 61861,
  "crop-free": 61862,
  "crop-landscape": 61863,
  "crop-original": 61864,
  "crop-portrait": 61865,
  "crop-square": 61866,
  "dashboard": 61867,
  "data-usage": 61868,
  "dehaze": 61869,
  "delete": 61870,
  "description": 61871,
  "desktop-mac": 61872,
  "desktop-windows": 61873,
  "details": 61874,
  "developer-mode": 61875,
  "devices": 61876,
  "dialer-sip": 61877,
  "dialpad": 61878,
  "directions": 61879,
  "directions-bike": 61880,
  "directions-bus": 61881,
  "directions-car": 61882,
  "directions-ferry": 61883,
  "directions-subway": 61884,
  "directions-train": 61885,
  "directions-transit": 61886,
  "directions-walk": 61887,
  "disc-full": 61888,
  "dnd-forwardslash": 61889,
  "dnd-on": 61890,
  "dns": 61891,
  "do-not-disturb": 61892,
  "dock": 61893,
  "domain": 61894,
  "done": 61895,
  "done-all": 61896,
  "drafts": 61897,
  "drive-eta": 61898,
  "dvr": 61899,
  "edit": 61900,
  "email": 61901,
  "equalizer": 61902,
  "error": 61903,
  "event": 61904,
  "event-available": 61905,
  "event-busy": 61906,
  "event-note": 61907,
  "exit-to-app": 61908,
  "expand-less": 61909,
  "expand-more": 61910,
  "explicit": 61911,
  "explore": 61912,
  "exposure": 61913,
  "exposure-minus-1": 61914,
  "exposure-minus-2": 61915,
  "exposure-plus-1": 61916,
  "exposure-plus-2": 61917,
  "exposure-zero": 61918,
  "extension": 61919,
  "face": 61920,
  "fast-forward": 61921,
  "fast-rewind": 61922,
  "favorite": 61923,
  "favorite-outline": 61924,
  "file-download": 61925,
  "file-upload": 61926,
  "filter": 61927,
  "filter-1": 61928,
  "filter-2": 61929,
  "filter-3": 61930,
  "filter-4": 61931,
  "filter-5": 61932,
  "filter-6": 61933,
  "filter-7": 61934,
  "filter-8": 61935,
  "filter-9": 61936,
  "filter-9-plus": 61937,
  "filter-b-and-w": 61938,
  "filter-center-focus": 61939,
  "filter-drama": 61940,
  "filter-frames": 61941,
  "filter-hdr": 61942,
  "filter-list": 61943,
  "filter-none": 61944,
  "filter-tilt-shift": 61945,
  "filter-vintage": 61946,
  "find-in-page": 61947,
  "find-replace": 61948,
  "flag": 61949,
  "flare": 61950,
  "flash-auto": 61951,
  "flash-off": 61952,
  "flash-on": 61953,
  "flight": 61954,
  "flip": 61955,
  "flip-to-back": 61956,
  "flip-to-front": 61957,
  "folder": 61958,
  "folder-open": 61959,
  "folder-shared": 61960,
  "folder-special": 61961,
  "format-align-center": 61962,
  "format-align-justify": 61963,
  "format-align-left": 61964,
  "format-align-right": 61965,
  "format-bold": 61966,
  "format-clear": 61967,
  "format-color-fill": 61968,
  "format-color-reset": 61969,
  "format-color-text": 61970,
  "format-indent-decrease": 61971,
  "format-indent-increase": 61972,
  "format-italic": 61973,
  "format-line-spacing": 61974,
  "format-list-bulleted": 61975,
  "format-list-numbered": 61976,
  "format-paint": 61977,
  "format-quote": 61978,
  "format-size": 61979,
  "format-strikethrough": 61980,
  "format-textdirection-l-to-r": 61981,
  "format-textdirection-r-to-l": 61982,
  "format-underline": 61983,
  "forum": 61984,
  "forward": 61985,
  "fullscreen": 61986,
  "fullscreen-exit": 61987,
  "functions": 61988,
  "gamepad": 61989,
  "games": 61990,
  "gesture": 61991,
  "get-app": 61992,
  "gps-fixed": 61993,
  "gps-not-fixed": 61994,
  "gps-off": 61995,
  "grade": 61996,
  "gradient": 61997,
  "grain": 61998,
  "grid-off": 61999,
  "grid-on": 62000,
  "group": 62001,
  "group-add": 62002,
  "group-work": 62003,
  "hdr-off": 62004,
  "hdr-on": 62005,
  "hdr-strong": 62006,
  "hdr-weak": 62007,
  "headset": 62008,
  "headset-mic": 62009,
  "healing": 62010,
  "hearing": 62011,
  "help": 62012,
  "high-quality": 62013,
  "highlight-remove": 62014,
  "history": 62015,
  "home": 62016,
  "hotel": 62017,
  "https": 62018,
  "image": 62019,
  "image-aspect-ratio": 62020,
  "import-export": 62021,
  "inbox": 62022,
  "info": 62023,
  "info-outline": 62024,
  "input": 62025,
  "insert-chart": 62026,
  "insert-comment": 62027,
  "insert-drive-file": 62028,
  "insert-emoticon": 62029,
  "insert-invitation": 62030,
  "insert-link": 62031,
  "insert-photo": 62032,
  "invert-colors": 62033,
  "invert-colors-off": 62034,
  "invert-colors-on": 62035,
  "iso": 62036,
  "keyboard": 62037,
  "keyboard-alt": 62038,
  "keyboard-arrow-down": 62039,
  "keyboard-arrow-left": 62040,
  "keyboard-arrow-right": 62041,
  "keyboard-arrow-up": 62042,
  "keyboard-backspace": 62043,
  "keyboard-capslock": 62044,
  "keyboard-control": 62045,
  "keyboard-hide": 62046,
  "keyboard-return": 62047,
  "keyboard-tab": 62048,
  "keyboard-voice": 62049,
  "label": 62050,
  "label-outline": 62051,
  "landscape": 62052,
  "language": 62053,
  "laptop": 62054,
  "laptop-chromebook": 62055,
  "laptop-mac": 62056,
  "laptop-windows": 62057,
  "launch": 62058,
  "layers": 62059,
  "layers-clear": 62060,
  "leak-add": 62061,
  "leak-remove": 62062,
  "lens": 62063,
  "link": 62064,
  "list": 62065,
  "live-help": 62066,
  "local-airport": 62067,
  "local-atm": 62068,
  "local-attraction": 62069,
  "local-bar": 62070,
  "local-cafe": 62071,
  "local-car-wash": 62072,
  "local-convenience-store": 62073,
  "local-drink": 62074,
  "local-florist": 62075,
  "local-gas-station": 62076,
  "local-grocery-store": 62077,
  "local-hospital": 62078,
  "local-hotel": 62079,
  "local-laundry-service": 62080,
  "local-library": 62081,
  "local-mall": 62082,
  "local-movies": 62083,
  "local-offer": 62084,
  "local-parking": 62085,
  "local-pharmacy": 62086,
  "local-phone": 62087,
  "local-pizza": 62088,
  "local-play": 62089,
  "local-post-office": 62090,
  "local-print-shop": 62091,
  "local-restaurant": 62092,
  "local-see": 62093,
  "local-shipping": 62094,
  "local-taxi": 62095,
  "location-city": 62096,
  "location-disabled": 62097,
  "location-history": 62098,
  "location-off": 62099,
  "location-on": 62100,
  "location-searching": 62101,
  "lock": 62102,
  "lock-open": 62103,
  "lock-outline": 62104,
  "looks": 62105,
  "looks-3": 62106,
  "looks-4": 62107,
  "looks-5": 62108,
  "looks-6": 62109,
  "looks-one": 62110,
  "looks-two": 62111,
  "loop": 62112,
  "loupe": 62113,
  "loyalty": 62114,
  "mail": 62115,
  "map": 62116,
  "markunread": 62117,
  "markunread-mailbox": 62118,
  "memory": 62119,
  "menu": 62120,
  "merge-type": 62121,
  "message": 62122,
  "messenger": 62123,
  "mic": 62124,
  "mic-none": 62125,
  "mic-off": 62126,
  "mms": 62127,
  "mode-comment": 62128,
  "mode-edit": 62129,
  "mood": 62130,
  "more": 62131,
  "more-horiz": 62132,
  "more-vert": 62133,
  "mouse": 62134,
  "movie": 62135,
  "movie-creation": 62136,
  "multitrack-audio": 62137,
  "my-library-add": 62138,
  "my-library-books": 62139,
  "my-library-music": 62140,
  "my-location": 62141,
  "nature": 62142,
  "nature-people": 62143,
  "navigate-before": 62144,
  "navigate-next": 62145,
  "navigation": 62146,
  "network-cell": 62147,
  "network-locked": 62148,
  "network-wifi": 62149,
  "new-releases": 62150,
  "nfc": 62151,
  "no-sim": 62152,
  "not-interested": 62153,
  "note-add": 62154,
  "notifications": 62155,
  "notifications-none": 62156,
  "notifications-off": 62157,
  "notifications-on": 62158,
  "notifications-paused": 62159,
  "now-wallpaper": 62160,
  "now-widgets": 62161,
  "open-in-browser": 62162,
  "open-in-new": 62163,
  "open-with": 62164,
  "pages": 62165,
  "pageview": 62166,
  "palette": 62167,
  "panorama": 62168,
  "panorama-fisheye": 62169,
  "panorama-horizontal": 62170,
  "panorama-vertical": 62171,
  "panorama-wide-angle": 62172,
  "party-mode": 62173,
  "pause": 62174,
  "pause-circle-fill": 62175,
  "pause-circle-outline": 62176,
  "payment": 62177,
  "people": 62178,
  "people-outline": 62179,
  "perm-camera-mic": 62180,
  "perm-contact-cal": 62181,
  "perm-data-setting": 62182,
  "perm-device-info": 62183,
  "perm-identity": 62184,
  "perm-media": 62185,
  "perm-phone-msg": 62186,
  "perm-scan-wifi": 62187,
  "person": 62188,
  "person-add": 62189,
  "person-outline": 62190,
  "phone": 62191,
  "phone-android": 62192,
  "phone-bluetooth-speaker": 62193,
  "phone-forwarded": 62194,
  "phone-in-talk": 62195,
  "phone-iphone": 62196,
  "phone-locked": 62197,
  "phone-missed": 62198,
  "phone-paused": 62199,
  "phonelink": 62200,
  "phonelink-off": 62201,
  "photo": 62202,
  "photo-album": 62203,
  "photo-camera": 62204,
  "photo-library": 62205,
  "picture-in-picture": 62206,
  "pin-drop": 62207,
  "place": 62208,
  "play-arrow": 62209,
  "play-circle-fill": 62210,
  "play-circle-outline": 62211,
  "play-download": 62212,
  "play-install": 62213,
  "play-shopping-bag": 62214,
  "playlist-add": 62215,
  "plus-one": 62216,
  "poll": 62217,
  "polymer": 62218,
  "portable-wifi-off": 62219,
  "portrait": 62220,
  "print": 62221,
  "public": 62222,
  "publish": 62223,
  "query-builder": 62224,
  "question-answer": 62225,
  "queue": 62226,
  "queue-music": 62227,
  "quick-contacts-dialer": 62228,
  "quick-contacts-mail": 62229,
  "radio": 62230,
  "radio-button-off": 62231,
  "radio-button-on": 62232,
  "rate-review": 62233,
  "receipt": 62234,
  "recent-actors": 62235,
  "redeem": 62236,
  "redo": 62237,
  "refresh": 62238,
  "remove": 62239,
  "remove-circle": 62240,
  "remove-circle-outline": 62241,
  "remove-red-eye": 62242,
  "repeat": 62243,
  "repeat-one": 62244,
  "replay": 62245,
  "reply": 62246,
  "reply-all": 62247,
  "report": 62248,
  "report-problem": 62249,
  "restaurant-menu": 62250,
  "restore": 62251,
  "ring-volume": 62252,
  "room": 62253,
  "rotate-left": 62254,
  "rotate-right": 62255,
  "satellite": 62256,
  "save": 62257,
  "schedule": 62258,
  "school": 62259,
  "screen-lock-landscape": 62260,
  "screen-lock-portrait": 62261,
  "screen-lock-rotation": 62262,
  "screen-rotation": 62263,
  "sd-card": 62264,
  "sd-storage": 62265,
  "search": 62266,
  "security": 62267,
  "select-all": 62268,
  "send": 62269,
  "settings": 62270,
  "settings-applications": 62271,
  "settings-backup-restore": 62272,
  "settings-bluetooth": 62273,
  "settings-cell": 62274,
  "settings-display": 62275,
  "settings-ethernet": 62276,
  "settings-input-antenna": 62277,
  "settings-input-component": 62278,
  "settings-input-composite": 62279,
  "settings-input-hdmi": 62280,
  "settings-input-svideo": 62281,
  "settings-overscan": 62282,
  "settings-phone": 62283,
  "settings-power": 62284,
  "settings-remote": 62285,
  "settings-system-daydream": 62286,
  "settings-voice": 62287,
  "share": 62288,
  "shop": 62289,
  "shop-two": 62290,
  "shopping-basket": 62291,
  "shopping-cart": 62292,
  "shuffle": 62293,
  "signal-cellular-0-bar": 62294,
  "signal-cellular-1-bar": 62295,
  "signal-cellular-2-bar": 62296,
  "signal-cellular-3-bar": 62297,
  "signal-cellular-4-bar": 62298,
  "signal-cellular-connected-no-internet-0-bar": 62299,
  "signal-cellular-connected-no-internet-1-bar": 62300,
  "signal-cellular-connected-no-internet-2-bar": 62301,
  "signal-cellular-connected-no-internet-3-bar": 62302,
  "signal-cellular-connected-no-internet-4-bar": 62303,
  "signal-cellular-no-sim": 62304,
  "signal-cellular-null": 62305,
  "signal-cellular-off": 62306,
  "signal-wifi-0-bar": 62307,
  "signal-wifi-1-bar": 62308,
  "signal-wifi-2-bar": 62309,
  "signal-wifi-3-bar": 62310,
  "signal-wifi-4-bar": 62311,
  "signal-wifi-off": 62312,
  "sim-card": 62313,
  "sim-card-alert": 62314,
  "skip-next": 62315,
  "skip-previous": 62316,
  "slideshow": 62317,
  "smartphone": 62318,
  "sms": 62319,
  "sms-failed": 62320,
  "snooze": 62321,
  "sort": 62322,
  "speaker": 62323,
  "speaker-notes": 62324,
  "spellcheck": 62325,
  "star-rate": 62326,
  "stars": 62327,
  "stay-current-landscape": 62328,
  "stay-current-portrait": 62329,
  "stay-primary-landscape": 62330,
  "stay-primary-portrait": 62331,
  "stop": 62332,
  "storage": 62333,
  "store": 62334,
  "store-mall-directory": 62335,
  "straighten": 62336,
  "style": 62337,
  "subject": 62338,
  "subtitles": 62339,
  "supervisor-account": 62340,
  "surround-sound": 62341,
  "swap-calls": 62342,
  "swap-horiz": 62343,
  "swap-vert": 62344,
  "swap-vert-circle": 62345,
  "switch-camera": 62346,
  "switch-video": 62347,
  "sync": 62348,
  "sync-disabled": 62349,
  "sync-problem": 62350,
  "system-update": 62351,
  "system-update-tv": 62352,
  "tab": 62353,
  "tab-unselected": 62354,
  "tablet": 62355,
  "tablet-android": 62356,
  "tablet-mac": 62357,
  "tag-faces": 62358,
  "tap-and-play": 62359,
  "terrain": 62360,
  "text-format": 62361,
  "textsms": 62362,
  "texture": 62363,
  "theaters": 62364,
  "thumb-down": 62365,
  "thumb-up": 62366,
  "thumbs-up-down": 62367,
  "time-to-leave": 62368,
  "timelapse": 62369,
  "timer": 62370,
  "timer-10": 62371,
  "timer-3": 62372,
  "timer-auto": 62373,
  "timer-off": 62374,
  "toc": 62375,
  "today": 62376,
  "tonality": 62377,
  "track-changes": 62378,
  "traffic": 62379,
  "transform": 62380,
  "translate": 62381,
  "trending-down": 62382,
  "trending-neutral": 62383,
  "trending-up": 62384,
  "tune": 62385,
  "turned-in": 62386,
  "turned-in-not": 62387,
  "tv": 62388,
  "undo": 62389,
  "unfold-less": 62390,
  "unfold-more": 62391,
  "usb": 62392,
  "verified-user": 62393,
  "vertical-align-bottom": 62394,
  "vertical-align-center": 62395,
  "vertical-align-top": 62396,
  "vibration": 62397,
  "video-collection": 62398,
  "videocam": 62399,
  "videocam-off": 62400,
  "view-agenda": 62401,
  "view-array": 62402,
  "view-carousel": 62403,
  "view-column": 62404,
  "view-day": 62405,
  "view-headline": 62406,
  "view-list": 62407,
  "view-module": 62408,
  "view-quilt": 62409,
  "view-stream": 62410,
  "view-week": 62411,
  "visibility": 62412,
  "visibility-off": 62413,
  "voice-chat": 62414,
  "voicemail": 62415,
  "volume-down": 62416,
  "volume-mute": 62417,
  "volume-off": 62418,
  "volume-up": 62419,
  "vpn-key": 62420,
  "vpn-lock": 62421,
  "wallet-giftcard": 62422,
  "wallet-membership": 62423,
  "wallet-travel": 62424,
  "warning": 62425,
  "watch": 62426,
  "wb-auto": 62427,
  "wb-cloudy": 62428,
  "wb-incandescent": 62429,
  "wb-irradescent": 62430,
  "wb-sunny": 62431,
  "web": 62432,
  "whatshot": 62433,
  "wifi-lock": 62434,
  "wifi-tethering": 62435,
  "work": 62436,
  "wrap-text": 62437
};

var MaterialDesign = createIconSet(glyphMap, 'MaterialDesign');

module.exports = MaterialDesign;
module.exports.glyphMap = glyphMap;

